pub enum PairSetupStep {
Send(Vec<u8>),
Done(AccessoryPairing),
}Expand description
The result of feeding one accessory response to PairSetupClient::handle.
Variants
Send(Vec<u8>)
The next controller message to transmit to the accessory (a TLV8 body).
Done(AccessoryPairing)
Pair Setup completed; the accessory pairing was established and verified.